#ifndef OPENSYNCMAPPING_H_
#define OPENSYNCMAPPING_H_

OPENSYNC_BEGIN_DECLS

#include "mapping/opensync_mapping_table.h"
#include "mapping/opensync_mapping_view.h"
#include "mapping/opensync_mapping_entry.h"
#include "mapping/opensync_mapping.h"

OPENSYNC_END_DECLS

#endif /*OPENSYNCMAPPING_H_*/
